interest

A simple Python module to calculate Simple Interest and Compound Interest.

Installation
bash
pip install interest

 from now on No need to memorise the formula just call the module and use it

